# coding: utf-8

"""
    Mentortools Deep Agent API

    FastAPI service for running Mentortools deep agent

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist

class DynamicSkillInput(BaseModel):
    """
    A skill passed as inline content, available to the agent at runtime.  # noqa: E501
    """
    name: StrictStr = Field(default=..., description="Unique skill name")
    description: StrictStr = Field(default=..., description="Short description shown in the agent prompt")
    content: StrictStr = Field(default=..., description="Full skill content (markdown)")
    allowed_tools: Optional[conlist(StrictStr)] = Field(default=None, description="Tools this skill may reference")
    __properties = ["name", "description", "content", "allowed_tools"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DynamicSkillInput:
        """Create an instance of DynamicSkillInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DynamicSkillInput:
        """Create an instance of DynamicSkillInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return DynamicSkillInput.parse_obj(obj)

        _obj = DynamicSkillInput.parse_obj({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "content": obj.get("content"),
            "allowed_tools": obj.get("allowed_tools")
        })
        return _obj


